"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = __importDefault(require("chai"));
var chai_as_promised_1 = __importDefault(require("chai-as-promised"));
var sinon_1 = __importDefault(require("sinon"));
var stateHandler_1 = require("./stateHandler");
var setupStatesModule = __importStar(require("./setupStates"));
chai_1.default.use(chai_as_promised_1.default);
var expect = chai_1.default.expect;
describe('#createProxyStateHandler', function () {
    var res;
    var mockResponse = {
        sendStatus: function (status) {
            res = status;
        },
        status: function (status) {
            res = status;
            return {
                send: function () { },
            };
        },
    };
    context('when valid state handlers are provided', function () {
        beforeEach(function () {
            sinon_1.default.stub(setupStatesModule, 'setupStates').returns(Promise.resolve());
        });
        afterEach(function () {
            setupStatesModule.setupStates.restore();
        });
        it('returns a 200', function () {
            var h = stateHandler_1.createProxyStateHandler({});
            return expect(h({}, mockResponse)).to.eventually.be.fulfilled.then(function () {
                expect(res).to.eql(200);
            });
        });
    });
    context('when there is a problem with a state handler', function () {
        beforeEach(function () {
            sinon_1.default
                .stub(setupStatesModule, 'setupStates')
                .returns(Promise.reject(new Error('state error')));
        });
        afterEach(function () {
            setupStatesModule.setupStates.restore();
        });
        it('returns a 500', function () {
            var h = stateHandler_1.createProxyStateHandler({});
            return expect(h({}, mockResponse)).to.eventually.be.fulfilled.then(function () {
                expect(res).to.eql(500);
            });
        });
    });
});
//# sourceMappingURL=stateHandler.spec.js.map