import express from 'express';
/**
 * Define needed state for given pacts
 */
export declare type StateHandler = (setup: boolean, parameters: Record<string, unknown>) => void;
export interface VerifierV3Options {
    provider: string;
    logLevel: string;
    providerBaseUrl: string;
    pactUrls?: string[];
    pactBrokerUrl?: string;
    providerStatesSetupUrl?: string;
    pactBrokerUsername?: string;
    pactBrokerPassword?: string;
    pactBrokerToken?: string;
    /**
     * The timeout in milliseconds for request filters and provider state handlers
     * to execute within
     */
    callbackTimeout?: number;
    publishVerificationResult?: boolean;
    providerVersion?: string;
    requestFilter?: express.RequestHandler;
    stateHandlers?: Record<string, StateHandler>;
    consumerVersionTags?: string | string[];
    providerVersionTags?: string | string[];
    consumerVersionSelectors?: ConsumerVersionSelector[];
    enablePending?: boolean;
    includeWipPactsSince?: string;
    disableSSLVerification?: boolean;
}
export interface ConsumerVersionSelector {
    pacticipant?: string;
    tag?: string;
    version?: string;
    latest?: boolean;
    all?: boolean;
}
export declare class VerifierV3 {
    private config;
    constructor(config: VerifierV3Options);
    /**
     * Verify a HTTP Provider
     */
    verifyProvider(): Promise<unknown>;
}
