"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var ramda_1 = require("ramda");
var configurationError_1 = __importDefault(require("../errors/configurationError"));
var logger_1 = __importDefault(require("../common/logger"));
var index_node_1 = __importDefault(require("../../native/index.node"));
var VerifierV3 = /** @class */ (function () {
    function VerifierV3(config) {
        this.config = config;
    }
    /**
     * Verify a HTTP Provider
     */
    VerifierV3.prototype.verifyProvider = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            var config = __assign({}, _this.config);
            if (ramda_1.isEmpty(_this.config)) {
                reject(new configurationError_1.default('No configuration provided to verifier'));
            }
            // This is just too messy to do on the rust side. neon-serde would have helped, but appears unmaintained
            // and is currently incompatible
            if (_this.config.consumerVersionSelectors) {
                config.consumerVersionSelectorsString = _this.config.consumerVersionSelectors.map(function (s) { return JSON.stringify(s); });
            }
            if (!_this.config.provider) {
                reject(new configurationError_1.default('Provider name is required'));
            }
            if ((ramda_1.isEmpty(_this.config.pactUrls) || !_this.config.pactUrls) &&
                !_this.config.pactBrokerUrl) {
                reject(new configurationError_1.default('Either a list of pactUrls or a pactBrokerUrl must be provided'));
            }
            try {
                index_node_1.default.verify_provider(_this.config, function (err, val) {
                    if (err || !val) {
                        logger_1.default.debug('In verify_provider callback: FAILED with', err, val);
                        reject(err);
                    }
                    else {
                        logger_1.default.debug('In verify_provider callback: SUCCEEDED with', val);
                        resolve(val);
                    }
                });
                logger_1.default.debug('Submitted test to verify_provider');
            }
            catch (e) {
                reject(e);
            }
        });
    };
    return VerifierV3;
}());
exports.VerifierV3 = VerifierV3;
//# sourceMappingURL=verifier.js.map